searchData={"items":[{"type":"module","title":"Hammer.Backend.Redis","doc":"Documentation for Hammer.Backend.Redis\n\nThis backend uses the [Redix](https://hex.pm/packages/redix) library to connect to Redis.\n\nThe backend process is started by calling `start_link`:\n\n    Hammer.Backend.Redis.start_link(\n      expiry_ms: 60_000 * 10,\n      redix_config: [host: \"example.com\", port: 5050]\n    )\n\nOptions are:\n\n- `expiry_ms`: Expiry time of buckets in milliseconds,\n  used to set TTL on Redis keys. This configuration is mandatory.\n- `redix_config`: Keyword list of options to the `Redix` redis client,\n  also aliased to `redis_config`\n- `key_prefix`: The prefix to use for all the redis keys (defaults to \"Hammer:Redis:\")\n- `redis_url`: String url of redis server to connect to\n  (optional, invokes Redix.start_link/2)","ref":"Hammer.Backend.Redis.html"},{"type":"function","title":"Hammer.Backend.Redis.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hammer.Backend.Redis.html#child_spec/1"},{"type":"function","title":"Hammer.Backend.Redis.count_hit/3","doc":"Record a hit in the bucket identified by `key`","ref":"Hammer.Backend.Redis.html#count_hit/3"},{"type":"function","title":"Hammer.Backend.Redis.count_hit/4","doc":"Record a hit in the bucket identified by `key`, with a custom increment","ref":"Hammer.Backend.Redis.html#count_hit/4"},{"type":"function","title":"Hammer.Backend.Redis.delete_buckets/2","doc":"Delete all buckets associated with `id`.","ref":"Hammer.Backend.Redis.html#delete_buckets/2"},{"type":"function","title":"Hammer.Backend.Redis.get_bucket/2","doc":"Retrieve information about the bucket identified by `key`","ref":"Hammer.Backend.Redis.html#get_bucket/2"},{"type":"function","title":"Hammer.Backend.Redis.start/0","doc":"","ref":"Hammer.Backend.Redis.html#start/0"},{"type":"function","title":"Hammer.Backend.Redis.start/1","doc":"","ref":"Hammer.Backend.Redis.html#start/1"},{"type":"function","title":"Hammer.Backend.Redis.start_link/0","doc":"","ref":"Hammer.Backend.Redis.html#start_link/0"},{"type":"function","title":"Hammer.Backend.Redis.start_link/1","doc":"","ref":"Hammer.Backend.Redis.html#start_link/1"},{"type":"function","title":"Hammer.Backend.Redis.stop/0","doc":"","ref":"Hammer.Backend.Redis.html#stop/0"},{"type":"type","title":"Hammer.Backend.Redis.bucket_info/0","doc":"","ref":"Hammer.Backend.Redis.html#t:bucket_info/0"},{"type":"type","title":"Hammer.Backend.Redis.bucket_key/0","doc":"","ref":"Hammer.Backend.Redis.html#t:bucket_key/0"},{"type":"extras","title":"Overview","doc":"# Overview\n\nA Redis backend for the Hammer rate-limiter\n\n[Hammer](https://github.com/ExHammer/hammer) is a rate-limiter for\nthe [Elixir](https://elixir-lang.org/) language. It's killer feature is a\npluggable backend system, allowing you to use whichever storage suits your\nneeds.\n\nThis package provides a Redis backend for Hammer, using\nthe [Redix](https://github.com/whatyouhide/redix) library to connect to the\nRedis server.\n\nTo get started, read\nthe [Hammer Tutorial](https://hexdocs.pm/hammer/tutorial.html) first, then add\nthe `hammer_backend_redis` dependency:\n\n```elixir\n    def deps do\n      [{:hammer_backend_redis, \"~> 6.1\"},\n      {:hammer, \"~> 6.0\"}]\n    end\n```\n\n... then configure the `:hammer` application to use the Redis backend:\n\n```elixir\nconfig :hammer,\n  backend: {Hammer.Backend.Redis, [expiry_ms: 60_000 * 60 * 2,\n                                   redix_config: [host: \"some.host\"]]}\n```\n\n(the `redix_config` arg is a keyword-list which is passed to Redix, it's also\naliased to `redis_config`, with an `s`)\n\nAnd that's it, calls to `Hammer.check_rate/3` and so on will use Redis to store\nthe rate-limit counters.","ref":"overview.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"6.2.0 (2024-12-04) - Changelog","doc":"","ref":"changelog.html#6-2-0-2024-12-04"},{"type":"extras","title":"Changed - Changelog","doc":"- Package updates\n- Add config to customize the redis prefix\n- Deprecate Elixir 1.12 as this are no longer supported","ref":"changelog.html#changed"},{"type":"extras","title":"6.1.2 (2022-11-11) - Changelog","doc":"","ref":"changelog.html#6-1-2-2022-11-11"},{"type":"extras","title":"Changed - Changelog","doc":"- Applied credo suggestions\n- Update dependencies","ref":"changelog.html#changed"},{"type":"extras","title":"6.1.1 (2022-11-11) - Changelog","doc":"","ref":"changelog.html#6-1-1-2022-11-11"},{"type":"extras","title":"Changed - Changelog","doc":"- package update and ownership transferred","ref":"changelog.html#changed"},{"type":"extras","title":"6.1.0 (2019-09-03) - Changelog","doc":"","ref":"changelog.html#6-1-0-2019-09-03"},{"type":"extras","title":"Changed - Changelog","doc":"- Return actual count upon bucket creation (thanks to @davelively14, https://github.com/ExHammer/hammer-backend-redis/pull/16)","ref":"changelog.html#changed"},{"type":"extras","title":"6.0.1 (2019-07-13) - Changelog","doc":"","ref":"changelog.html#6-0-1-2019-07-13"},{"type":"extras","title":"Added - Changelog","doc":"- Accept an optional `redis_url` option","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Updated dependencies in test environment (thanks to @ono, https://github.com/ExHammer/hammer-backend-redis/pull/14)","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a crash in `delete_buckets` (thanks to @ono, https://github.com/ExHammer/hammer-backend-redis/pull/15)","ref":"changelog.html#fixed"},{"type":"extras","title":"6.0.0 (2018-10-13) - Changelog","doc":"","ref":"changelog.html#6-0-0-2018-10-13"},{"type":"extras","title":"Changed - Changelog","doc":"- Raise an error if `expiry_ms` is not configured explicitly\n- Update the `redix` dependency to `~> 0.8`","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Actually honor `:redis_config`, as is claimed in the documentation","ref":"changelog.html#fixed"},{"type":"extras","title":"5.0.0 (2018-10-13) - Changelog","doc":"","ref":"changelog.html#5-0-0-2018-10-13"},{"type":"extras","title":"Changed - Changelog","doc":"- Update to the new custom-increment api","ref":"changelog.html#changed"},{"type":"extras","title":"4.0.3 (2018-05-08) - Changelog","doc":"","ref":"changelog.html#4-0-3-2018-05-08"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix a rare crash, again related to race-conditions\n  (https://github.com/ExHammer/hammer-backend-redis/issues/11#issuecomment-387202359)","ref":"changelog.html#fixed"},{"type":"extras","title":"4.0.2 (2018-04-27) - Changelog","doc":"","ref":"changelog.html#4-0-2-2018-04-27"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed race-condition, really this time\n  (https://github.com/ExHammer/hammer-backend-redis/issues/11)","ref":"changelog.html#fixed"},{"type":"extras","title":"4.0.1 (2018-04-24) - Changelog","doc":"","ref":"changelog.html#4-0-1-2018-04-24"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a race-condition that could cause crashes\n  (https://github.com/ExHammer/hammer-backend-redis/issues/11)","ref":"changelog.html#fixed"},{"type":"extras","title":"4.0.0 (2018-04-23) - Changelog","doc":"","ref":"changelog.html#4-0-0-2018-04-23"},{"type":"extras","title":"Changed - Changelog","doc":"- Update to `Hammer 4.0`","ref":"changelog.html#changed"},{"type":"extras","title":"3.0.0 (2018-02-20) - Changelog","doc":"","ref":"changelog.html#3-0-0-2018-02-20"},{"type":"extras","title":"Changed - Changelog","doc":"- Require elixir >= 1.6","ref":"changelog.html#changed"},{"type":"extras","title":"2.0.0 (2017-09-24) - Changelog","doc":"","ref":"changelog.html#2-0-0-2017-09-24"},{"type":"extras","title":"Changed - Changelog","doc":"- Updated to new Hammer API","ref":"changelog.html#changed"},{"type":"extras","title":"1.0.0 (2017-08-27) - Changelog","doc":"","ref":"changelog.html#1-0-0-2017-08-27"},{"type":"extras","title":"Changed - Changelog","doc":"- `hammer_backend_redis` now explicitly depends on `hammer`\n- Implement the `Hammer.Backend` behaviour\n- Alias `redix_config` to `redis_config` in the config list, for convenience","ref":"changelog.html#changed"},{"type":"extras","title":"0.1.0 (2017-07-31) - Changelog","doc":"Initial release.","ref":"changelog.html#0-1-0-2017-07-31"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}